@@ -11,12 +11,17 @@ xmlTreeParse <-
 function(file, ignoreBlanks = TRUE, handlers=NULL,
            replaceEntities=FALSE, asText=FALSE, trim=TRUE, validate=FALSE, getDTD=TRUE,
            isURL=FALSE, asTree = FALSE, addAttributeNamespaces = FALSE,
-           useInternalNodes = FALSE)
+           useInternalNodes = FALSE, isSchema = FALSE,
+           fullNamespaceInfo = FALSE)
 {
-  if(missing(isURL)) {
+  if(missing(isURL)) 
     isURL <- length(grep("^http://",file)) | length(grep("^ftp://",file)) | length(grep("^file://", file))
-  }
 
+
+  oldValidate = xmlValidity()
+  xmlValidity(validate)
+  on.exit(xmlValidity(oldValidate))
+  
     # check whether we are treating the file name as
     # a) the XML text itself, or b) as a URL.
     # Otherwise, check if the file exists and report an error.
@@ -33,7 +38,8 @@ function(file, ignoreBlanks = TRUE, handlers=NULL,
               as.logical(ignoreBlanks), as.logical(replaceEntities),
               as.logical(asText), as.logical(trim), as.logical(validate), as.logical(getDTD),
               as.logical(isURL), as.logical(addAttributeNamespaces),
-              as.logical(useInternalNodes), FALSE)
+              as.logical(useInternalNodes), FALSE, as.logical(isSchema),
+              as.logical(fullNamespaceInfo))
 
 
  if(!missing(handlers) & !as.logical(asTree))
@@ -41,3 +47,13 @@ function(file, ignoreBlanks = TRUE, handlers=NULL,
 
  ans
 }
+
+
+
+
+xmlValidity =
+function(val = integer(0))
+{
+  .Call("RS_XML_getDefaultValiditySetting", as.integer(val))
+}
+
